@@ -38,6 +38,10 @@ pub fn parse_opts() -> App<'static, 'static> {
             .short("p")
             .long("pop")
             .help("Remove from top of stack"))
+        .arg(Arg::with_name("unshift")
+            .short("u")
+            .long("unshift")
+            .help("Add to bottom of stack"))
         .arg(Arg::with_name("shift")
             .short("s")
             .long("shift")
